#include "help.h"
#include "ui_help.h"

#include <QtCore/QCoreApplication>
#include <QDesktopServices>
#include <QUrl>


Help::Help(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Help)
{
    ui->setupUi(this);
}

Help::~Help()
{
    delete ui;
}


void Help::on_pushButtonTalk_clicked()
{
     QDesktopServices::openUrl(QUrl("http://talk.maemo.org/showthread.php?t=89529"));
}

//"http://talk.maemo.org/showthread.php?t="

void Help::on_pushButtonWiki_clicked()
{
     QDesktopServices::openUrl(QUrl("http://wiki.maemo.org/Bander"));
}

void Help::on_pushButtonGf_clicked()
{
     QDesktopServices::openUrl(QUrl("http://www.gentleface.com"));
}
